off_broadway_mqtt v0.1.0 OffBroadway.MQTT.Data View Source
Defines a data structure for the data passed around in the
Broadway.Message.t/0 struct.
:acc- The data that is being processed in a pipeline.:topic- A list with the fragments of the topic the data is coming from.:meta- A with map arbitrary metadata.
Link to this section Summary
Types
Type for the internal data structure passed around with the
Broadway.Message.t/0.
Link to this section Types
Type for the internal data structure passed around with the
Broadway.Message.t/0.
:acc- The data that is being processed in a pipeline.:topic- A list with the fragments of the topic the data is coming from.:meta- A with map arbitrary metadata.